========
Changelog
=========

v0.6.0b2 (2023-09-17)
------------------

* Refactor GitHub Actions workflow so it can publish to PyPI.
* Refactor GitHub Actions workflow so it can work with matrix of Django/Python/Postgres versions.

v0.6.0b1 (2023-09-11)
------------------

* Drop Django <= 3.1 support.
* Drop Python <= 3.7 support.
* Support Python 3.9, 3.10, and 3.11,
* Support Django 3.2, 4.1, and 4.2.
* Drop Travis CI in favor of GitHub Actions.
* Refactor Markdown files in favor of reStructuredText.
* Fork from the `original project <https://github.com/mariocesar/django-ltree>`__.
* Publish as full release.


v0.6.0a (2023-09-10)
------------------

* Drop Django <=3.1 support.
* Drop Python <=3.7 support.
* Support Python 3.9, 3.10, and 3.11,
* Support Django 3.2, 4.1, and 4.2.
* Drop Travis CI in favor of GitHub Actions.
* Refactor Markdown files in favor of reStructuredText.
* Fork from the `original project <https://github.com/mariocesar/django-ltree>`__.
